@@ -1,6 +1,6 @@
 import sys
 
-from src.yaml_extender.cli import main
+from yaml_extender.cli import main
 
 if __name__ == "__main__":
     sys.exit(main())
