@@ -1,13 +1,12 @@
 import argparse
-import logging
 import sys
 
 from pathlib import Path
 from typing import List, Dict
 
-from src.yaml_extender.resolver import reference_resolver
-from src.yaml_extender.xyml_file import XYmlFile
-from src.yaml_extender.logger import get_logger
+from yaml_extender.resolver import reference_resolver
+from yaml_extender.xyml_file import XYmlFile
+from yaml_extender.logger import get_logger
 
 LOGGER = get_logger()
 
@@ -16,6 +15,7 @@ def main():
     parser = argparse.ArgumentParser()
     parser.add_argument("input", help="Input yaml file to be parsed", type=Path)
     parser.add_argument("output", help="Output file to save to", type=Path)
+    parser.add_argument("-i", "--include", help="Include paths", type=Path, nargs="*")
     args, unknown_args = parser.parse_known_args()
 
     if not args.input.is_file:
